@@ -1,6 +1,7 @@
-from flask import Flask, Blueprint
 from importlib import import_module
 
+from flask import Blueprint, Flask
+
 from ..helper import get_import_name, import_attr
 
 
@@ -11,8 +12,8 @@ def loader(app: Flask):
 
     apis = app.config.get("APIS", [])
     import_name = get_import_name(app)
-    api: Blueprint = import_attr(import_name + "api.api")
-    prefix = "api."
+    api: Blueprint = import_attr(import_name + "apis.api")
+    prefix = "apis."
     for name in apis:
         res = name
         if not name.startswith(prefix):
@@ -21,7 +22,7 @@ def loader(app: Flask):
         try:
             res = import_module(import_name + res)
         except ImportError:
-            res = import_module(name)
+            res = import_module(name.lstrip(prefix))
 
         endpoint = res.endpoint
         url_prefix = res.url_prefix
