@@ -1,9 +1,11 @@
-from flask import Flask, Blueprint
-from flask_apispec import FlaskApiSpec
 from importlib import import_module
 
+from flask import Flask
+
+from zemfrog.globals import apispec as docs
+
 from ..decorators import api_doc
-from ..helper import get_import_name, import_attr
+from ..helper import get_import_name
 
 
 def loader(app: Flask):
@@ -15,7 +17,6 @@ def loader(app: Flask):
         return
 
     import_name = get_import_name(app)
-    docs: FlaskApiSpec = import_attr(import_name + "extensions.apispec.docs")
     urls = import_module(import_name + "urls")
     docs_params = urls.docs
     routes = urls.routes
@@ -25,16 +26,15 @@ def loader(app: Flask):
         docs.register(view)
 
     apis = app.config.get("APIS", [])
-    api_prefix = "api."
+    api_prefix = "apis."
     for name in apis:
-        res = name
         if not name.startswith(api_prefix):
-            res = api_prefix + res
+            name = api_prefix + name
 
         try:
-            res = import_module(import_name + res)
+            res = import_module(import_name + name)
         except ImportError:
-            res = import_module(name)
+            res = import_module(name.lstrip(api_prefix))
 
         docs_params = res.docs
         routes = res.routes
@@ -48,20 +48,15 @@ def loader(app: Flask):
 
     blueprints = app.config.get("BLUEPRINTS", [])
     for name in blueprints:
+        urls = name + ".urls"
         try:
-            bp = import_name + name + ".routes.blueprint"
-            bp: Blueprint = import_attr(bp)
-            urls = import_name + name + ".urls"
+            urls = import_name + urls
             urls = import_module(urls)
-            docs_params = urls.docs
-            routes = urls.routes
         except (ImportError, AttributeError):
-            bp = name + ".routes.blueprint"
-            bp: Blueprint = import_attr(bp)
-            urls = name + ".urls"
             urls = import_module(urls)
-            docs_params = urls.docs
-            routes = urls.routes
+
+        docs_params = urls.docs
+        routes = urls.routes
 
         for _, view, _ in routes:
             if docs_params:
